.. _pydl.goddard:

==================================
Goddard Utilities (`pydl.goddard`)
==================================

Introduction
------------

This is a placeholder for Goddard Utilities documentation.

Components
----------

.. toctree::
   :maxdepth: 1

   goddard_astro.rst
   goddard_math.rst
   goddard_misc.rst

.. automodapi:: pydl.goddard
   :no-inheritance-diagram:
